aboutsummaryrefslogtreecommitdiff
path: root/mod/riverdashboard/views/default/riverdashboard/css.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/riverdashboard/views/default/riverdashboard/css.php')
-rw-r--r--mod/riverdashboard/views/default/riverdashboard/css.php72
1 files changed, 36 insertions, 36 deletions
diff --git a/mod/riverdashboard/views/default/riverdashboard/css.php b/mod/riverdashboard/views/default/riverdashboard/css.php
index a09a32712..18ba7c0dc 100644
--- a/mod/riverdashboard/views/default/riverdashboard/css.php
+++ b/mod/riverdashboard/views/default/riverdashboard/css.php
@@ -4,10 +4,10 @@
*
*/
?>
-#riverdashboard_updates {
+#riverdashboard-updates {
border-bottom:1px solid #cccccc;
}
-#riverdashboard_updates a.update_link {
+#riverdashboard-updates a.update-link {
display: inline-table;
color:white;
font-weight: bold;
@@ -18,47 +18,47 @@
-webkit-border-radius: 10px;
-moz-border-radius: 10px;
}
-#riverdashboard_updates a.update_link:hover {
+#riverdashboard-updates a.update-link:hover {
background: #4690D6 url("<?php echo elgg_get_site_url(); ?>mod/riverdashboard/graphics/refresh.png") no-repeat 5px -22px;
color:white;
text-decoration: none;
}
-.riverdashboard_filtermenu {
+.riverdashboard-filtermenu {
margin:10px 0 10px 0;
float:right;
}
/* RIVER ENTRY */
-.river_item {
+.river-item {
border-bottom:1px solid #cccccc;
padding:7px 0 7px 0;
}
-.river_item p {
+.river-item p {
margin:0;
}
-.river_item .entity_subtext {
+.river-item .entity-subtext {
display: block;
line-height: 1.4em;
}
-.river_item_useravatar {
+.river-item-useravatar {
float:left;
margin-top:3px;
margin-left:1px;
}
-.river_item_contents {
+.river-item-contents {
margin-left:55px;
}
-.river_item_contents a {
+.river-item-contents a {
font-weight: bold;
}
-.river_content_display {
+.river-content-display {
border-left:1px solid #DDDDDD;
font-size:85%;
line-height:1.5em;
margin:8px 0 5px 0;
padding-left:5px;
}
-.following_icon {
+.following-icon {
width:20px;
height:25px;
margin:0 2px 0 2px;
@@ -66,11 +66,11 @@
}
/* LATEST COMMENTS IN RIVER */
-.river_comments_tabs {
+.river-comments-tabs {
max-height: 19px;
overflow:hidden;
}
-.river_comments {
+.river-comments {
-moz-border-radius-bottomleft:5px;
-moz-border-radius-bottomright:5px;
-moz-border-radius-topleft:5px;
@@ -81,65 +81,65 @@
-webkit-border-bottom-left-radius:5px;
background-color: #eeeeee;
}
-.river_comment {
+.river-comment {
padding:3px;
border-bottom:1px solid white;
}
-.river_comment.penultimate {
+.river-comment.penultimate {
}
-.river_comment.latest {
+.river-comment.latest {
}
/* hidden inline comment form */
-.river_comment_form.hidden {
+.river-comment_form.hidden {
padding:5px;
height:26px;
}
-.river_comment_form.hidden .input-text {
+.river-comment_form.hidden .input-text {
width:560px;
padding:3px;
}
#profile_content .river_comment_form.hidden .input-text { /* when activity is displayed on profile page */
width:535px;
}
-.river_comment_form.hidden .submit-button {
+.river-comment_form.hidden .submit-button {
margin:0 0 0 10px;
float:right;
}
-.river_link_divider {
+.river-link-divider {
color:#999999;
font-style: normal;
}
-.river_item_contents .river_comment_form_button,
-.river_item_contents .river_user_like_button {
+.river-item-contents .river-comment-form-button,
+.river-item-contents .river_user-like-button {
font-weight:normal;
font-style: normal;
}
-.river_item_contents .river_comment_form_button {
+.river-item-contents .river-comment-form-button {
margin-left: 7px;
}
/* hidden list of users that liked item */
-.river_item .elgg_likes_user {
+.river-item .elgg-likes-user {
border-bottom:1px solid white;
padding:3px;
}
-.river_item .elgg_likes_user .entity_listing_icon {
+.river-item .elgg-likes-user .entity-listing-icon {
margin:3px 0 4px 2px;
}
-.river_item .elgg_likes_user .entity_listing_info {
+.river-item .elgg-likes-user .entity-listing-info {
width:635px;
}
-#profile_content .river_item .elgg_likes_user .entity_listing_info { /* when likes is displayed on profile page activity stream */
+#profile-content .river-item .elgg-likes-user .entity-listing-info { /* when likes is displayed on profile page activity stream */
width:600px;
}
-.river_item .elgg_likes_user .entity_metadata {
+.river-item .elgg-likes-user .entity-metadata {
margin-top:3px;
}
-.river_item p.elgg_likes_owner {
+.river-item p.elgg-likes-owner {
padding-top:0;
}
-.river_item a.river_more_comments {
+.river-item a.river-more-comments {
display:block;
float:right;
padding:1px 7px 1px 7px;
@@ -154,17 +154,17 @@
-webkit-border-top-left-radius:4px;
-webkit-border-top-right-radius:4px;
}
-.river_item a.river_more_comments.off {
+.river-item a.river-more-comments.off {
background-color: white;
}
-.river_item .river_comment_owner_icon {
+.river-item .river-comment-owner-icon {
float:left;
margin:3px 8px 4px 2px;
}
-.river_item .river_comment_contents {
+.river-item .river-comment-contents {
margin-left:34px;
}
-a.river_more_comments {
+a.river-more-comments {
float:right;
font-size:85%;
padding-right:7px;
@@ -81,65 +81,65 @@
padding:3px;
}
-#profile_content .river_comment_form.hidden .input-text { /* when activity is displayed on profile page */
+#profile-content .river-comment_form.hidden .input-text { /* when activity is displayed on profile page */
width:535px;
}